@@ -23,7 +23,9 @@ class BaseElement(Model):
     deleted: Optional[datetime] = Field(
         None, description="Timestamp element was removed from the network"
     )
-    tags: Optional[Dict[str, str]] = None
+    group_uid: Optional[str] = Field(
+        None, description="UID of group to which link belongs"
+    )
 
     @validator("display_name", always=True)
     def default_display_name(cls, v: Any, values: Dict[str, Any]) -> Any:
