@@ -1,7 +1,7 @@
+import json
 from typing import Any, Dict, List, Set
 
 import pkg_resources
-from fastapi.encoders import jsonable_encoder
 
 from kisters.network_store.model_library.base import BaseElement
 
@@ -56,4 +56,4 @@ def element_from_dict(obj: Dict[str, Any], validate: bool = True) -> BaseElement
 
 
 def element_to_dict(elem: BaseElement) -> Dict[str, Any]:
-    return jsonable_encoder(elem, exclude_none=True)
+    return json.loads(elem.json(exclude_none=True))
